<?php
/**
 * twinkle Theme Post Gallery
 *
 * @package twinkle
 */

add_filter('post_gallery', 'twinkle_post_gallery', 10, 2);
function twinkle_post_gallery($output, $attr) {
  
    global $post;

    if (isset($attr['orderby'])) {
      $attr['orderby'] = sanitize_sql_orderby($attr['orderby']);
      if (!$attr['orderby'])
        unset($attr['orderby']);
    }

    extract(shortcode_atts(array(
      'order' => 'ASC',
      'orderby' => 'menu_order ID',
      'id' => $post->ID,
      'itemtag' => 'dl',
      'icontag' => 'dt',
      'captiontag' => 'dd',
      'columns' => 3,
      'size' => 'thumbnail',
      'include' => '',
      'auto' => 0,
      'exclude' => ''
    ), $attr));

    $id = intval($id);
    if ('RAND' == $order) $orderby = 'none';

    if (!empty($include)) {
      $include = preg_replace('/[^0-9,]+/', '', $include);

      $_attachments = get_posts(array(
        'include' => $include,
        'post_status' => 'inherit',
        'post_type' => 'attachment',
        'post_mime_type' => 'image',
        'order' => $order,
        'orderby' => $orderby
      ));

      $attachments = array();

      foreach ($_attachments as $key => $val) {
        $attachments[$val->ID] = $_attachments[$key];
      }
    }

    if (empty($attachments)) return '';


    if($columns == 'slider') { 

      $output = '';
      $output .= '<div class="twinkle-gallery-carousels twinkle-post-gallery-carousel">';
        $output .= '<div class="twinkle-big-gallery owl-carousel">';

          foreach ($attachments as $id => $attachment) : 
              $src = wp_get_attachment_image_src($id, 'twinkle-large_equal');
              $image_alt = get_post_meta( $id, '_wp_attachment_image_alt', true);
              $image_title = get_the_title( $id );

              $link_img = wp_get_attachment_image_src($id, 'twinkle-large_equal');
              $caption = (strlen($attachment->post_content) > 0 ? $attachment->post_content : $attachment->post_excerpt);
       
              if(!empty($src[0])): 
                $output .= '<div class="twinkle-carousel-single-image" data-id="wp-image-'.$id.'">';
                  
                  $output .= '<figure class="gallery-item">'."\n";
                    $output .= '<a href="'. esc_url($link_img[0]) .'" data-caption="'. esc_attr($caption) .'">'."\n";
                      $output .= '<img src="' . esc_url($src[0]) . '" alt="' . esc_attr($image_alt) .'"/>';
                    $output .= '</a>';
                    $output .= '</figure>';
                    $output .= '<div class="carousel-slide-title-wrapper">';
                      if($caption == ''){

                      }else {
                        $output .= '<span class="slide-title">' . esc_html($caption) .'</span>';
                      }
                    
                  $output .= '</div>';
                $output .= '</div>';
                

              endif;

          endforeach;
        
        $output .= '</div>'; //Closing twinkle-big-gallery

        $output .= '<div class="twinkle-thumbs-gallery owl-carousel">';

          foreach ($attachments as $id => $attachment) : 
              $src_small = wp_get_attachment_image_src($id, 'twinkle-small_equal');
              $image_alt_small = get_post_meta( $id, '_wp_attachment_image_alt', true);
              
              if(!empty($src_small[0])): 
                $output .= '<div class="twinkle-carousel-single-image" id="wp-image-'. esc_attr($id) .'">';
                  $output .= '<img src="' . esc_url($src_small[0]) . '" alt="' . esc_attr($image_alt_small) . '"/>';
                $output .= '</div>';
              endif;

          endforeach;

        $output .= '</div>'; //Closing twinkle-thumbs-gallery

      $output .= '</div>'; //Closing twinkle-gallery-carousels

    } else {
      $output = '<div class="gallery clear gallery-columns-'. esc_attr($columns) .' gallery-size-'. esc_attr($size) .'">'."\n";

        foreach ($attachments as $id => $attachment) :
            $link_img = wp_get_attachment_image_src($id, 'large_equal');
            $img = wp_get_attachment_image_src($id, $size);
            $caption = (strlen($attachment->post_content) > 0 ? $attachment->post_content : $attachment->post_excerpt);

            $output .= '<figure class="gallery-item">'."\n";
              $output .= '<div class="gallery-icon '. ($link_img[1] / $link_img[2] > 1 ? 'landscape' : $link_img[1] / $link_img[2] === 1 ? 'square' : 'portrait').'">'."\n";
                $output .= '<a href="'. esc_url($link_img[0]) .'" data-caption="'. esc_attr($caption) .'">'."\n";
                  $output .= '<img class="wp-image-'. esc_attr($id) .' attachment-'. esc_attr($size) .'" src="'. esc_url($img[0]) .'" data-src="'. esc_url($img[0]) .'" width="'. esc_attr($img[1]) .'" height="'. esc_attr($img[2]) .'" alt="'. esc_attr( get_post_meta($id, '_wp_attachment_image_alt', true) ).'">'."\n";
                $output .= '</a>'."\n";
              $output .= '</div>';
            $output .= '</figure>'."\n";
        endforeach;

      $output .= "</div>\n";

    }

  return $output;

}


// Add Slider Option to WP Gallery
add_action( 'wp_enqueue_media', 'twinkle_gallery_slider_columns' );
function twinkle_gallery_slider_columns(){
  
  add_action( 'admin_print_footer_scripts', 'twinkle_gallery_slider_columns_script', 999);

}

function twinkle_gallery_slider_columns_script(){ ?>
  <script type="text/javascript">
    jQuery(function(){
      if(wp.media.view.Settings.Gallery){
        wp.media.view.Settings.Gallery = wp.media.view.Settings.extend({
          className: "collection-settings gallery-settings",
          template: wp.media.template("gallery-settings"),
          render: function() {
            wp.media.View.prototype.render.apply( this, arguments );

            // Append an option for Slider
            var $s = this.$('select.columns');
            if(!$s.find('option[value="slider"]').length){
              $s.append('<option value="slider">Slider</option>');
            }

            // Select the correct values.
            _( this.model.attributes ).chain().keys().each( this.update, this );
            return this;
          }
        });
      }
    });
  </script>

  <?php
}