<?php
/**
 * twinkle Theme Customizer
 *
 * @package twinkle
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */

function twinkle_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

}
add_action( 'customize_register', 'twinkle_customize_register' );

/**
 * Add the theme configuration
 */
twinkle_Kirki::add_config( 'twinkle', array(
    'option_type' => 'theme_mod',
    'capability'  => 'edit_theme_options',
) );

/**
 * Add General Settings
 */
twinkle_Kirki::add_section( 'general', array(
    'title'      => esc_html__( 'General Settings', 'twinkle' ),
    'priority'   => 1,
    'capability' => 'edit_theme_options',
) );

    

     twinkle_Kirki::add_field( 'twinkle', array(
      'type'        => 'radio',
      'settings'    => 'archive_style',
      'label'       => __( 'Archive Style', 'twinkle' ),
      'description' => esc_html__( 'Choose to display only the excerpt or the full post content on archive / overview pages.', 'twinkle' ),
      'section'     => 'general',
      'default'     => 'excerpt',
      'priority'    => 10,
      'choices'     => array(
          'excerpt'       => esc_html__( 'Excerpt (recommended)', 'twinkle' ),
          'full'          => esc_html__( 'Full Content', 'twinkle' ),
      ),
  ) );

twinkle_Kirki::add_section( 'homepage', array(
    'title'      => esc_html__( 'Homepage Settings', 'twinkle' ),
    'priority'   => 1,
    'capability' => 'edit_theme_options',
) );

    twinkle_Kirki::add_field( 'twinkle', array(
        'type'        => 'checkbox',
        'settings'    => 'enable_featured_posts_slider',
        'label'       => __( 'Enable featured posts slider?', 'twinkle' ),
        'section'     => 'homepage',
        'default'     => '1',
        'priority'    => 10,
    ) );

    twinkle_Kirki::add_field( 'twinkle', array(
        'type'        => 'radio',
        'settings'    => 'blog_style',
        'label'       => __( 'Blog Style', 'twinkle' ),
        'section'     => 'homepage',
        'default'     => 'first-large',
        'priority'    => 10,
        'choices'     => array(
            'large'         => esc_html__( 'Large Posts', 'twinkle' ),
            'grid'          => esc_html__( 'Grid Posts', 'twinkle' ),
            'first-large'   => esc_html__( 'First large - rest grid', 'twinkle' ),
        ),
    ) );

/**
 * Add the typography section
 */
twinkle_Kirki::add_section( 'typography', array(
    'title'      => esc_html__( 'Typography', 'twinkle' ),
    'priority'   => 2,
    'capability' => 'edit_theme_options',
) );

    /**
     * Add the body-typography control
     */
    twinkle_Kirki::add_field( 'twinkle', array(
        'type'        => 'typography',
        'settings'    => 'body_typography',
        'label'       => esc_html__( 'Body Typography', 'twinkle' ),
        'description' => esc_html__( 'Select the main typography options for your site.', 'twinkle' ),
        'help'        => esc_html__( 'The typography options you set here apply to all content on your site.', 'twinkle' ),
        'section'     => 'typography',
        'priority'    => 10,
        'default'     => array(
            'font-family'    => 'Lora',
            'variant'        => '400',
            'font-size'      => '15px',
            'line-height'    => '1.8',
            'color'          => '#333333',
        ),
        'output' => array(
            array(
                'element' => 'body',
            ),
        ),
    ) );

     twinkle_Kirki::add_field( 'twinkle', array(
        'type'        => 'typography',
        'settings'    => 'body_typography_bold',
        'label'       => esc_html__( 'Body Typography Bold', 'twinkle' ),
        'description' => esc_html__( 'Choose the font you want to use for "bold" content elements (should be the same as body typography)', 'twinkle' ),
        'help'        => esc_html__( 'The typography options you set here apply to all content on your site.', 'twinkle' ),
        'section'     => 'typography',
        'priority'    => 10,
        'default'     => array(
            'font-family'    => 'Lora',
            'variant'        => '400',
            'font-size'      => '15px',
            'line-height'    => '1.8',
            'color'          => '#333333',
        ),
        'output' => array(
            array(
                'element' => 'body strong',
            ),
            array(
                'element' => 'body b',
            ),
        ),
    ) );

    
    twinkle_Kirki::add_field( 'twinkle', array(
        'type'        => 'typography',
        'settings'    => 'headers_typography',
        'label'       => esc_html__( 'Headers Typography', 'twinkle' ),
        'description' => esc_html__( 'Select the typography options for your headers.', 'twinkle' ),
        'help'        => esc_html__( 'The typography options you set here will override the Body Typography options for all headers on your site (post titles, widget titles etc).', 'twinkle' ),
        'section'     => 'typography',
        'priority'    => 10,
        'default'     => array(
            'font-family'    => 'Roboto',
            'variant'        => '400',
        ),
        'output' => array(
            array(
                'element' => array( 'h1', 'h2', 'h3', 'h4', 'h5', 'h6', '.h1', '.h2', '.h3', '.h4', '.h5', '.h6' ),
            ),
            array(
                'element' => array( 'p.dropcap:first-letter', 'blockquote p' ),
            )
        ),
    ) );

    
    twinkle_Kirki::add_field( 'twinkle', array(
        'type'        => 'typography',
        'settings'    => 'menu_typography',
        'label'       => esc_html__( 'Menu Typography', 'twinkle' ),
        'description' => esc_html__( 'Select the typography options for your menu.', 'twinkle' ),
        'help'        => esc_html__( 'The typography options you set here will override the Body Typography options for all headers on your site (post titles, widget titles etc).', 'twinkle' ),
        'section'     => 'typography',
        'priority'    => 10,
        'default'     => array(
            'font-family'    => 'Lato',
            'variant'        => '400',
            'font-size'      => '13px',
            // 'line-height'    => '1.5',
            'letter-spacing' => '0',
            'color'          => '#333333',
            'text-transform' => 'Uppercase',
        ),
        'output' => array(
            array(
                'element' => array( '#main-menu a' ),
            ),
            array(
                'element' => array( '.post-categories a, .featured-post-categories a, .featured-post-link' ),
            ),
        ),
    ) );

twinkle_Kirki::add_section( 'colors', array(
    'title'      => esc_html__( 'Theme Colors', 'twinkle' ),
    'priority'   => 2,
    'capability' => 'edit_theme_options',
) );

    twinkle_Kirki::add_field( 'twinkle', array(
        'type'        => 'color',
        'settings'    => 'primary_color',
        'label'       => __( 'Primary Color', 'twinkle' ),
        'section'     => 'colors',
        'default'     => '#0088CC',
        'priority'    => 10,
        'alpha'       => false,
        'output'    => array(
            array(
              'choice'    => 'default',
              'element'   => 'a',
              'property'  => 'color',
            ),
            array(
              'choice'    => 'default',
              'element'   => 'a:hover',
              'property'  => 'color',
            ),
            array(
              'choice'    => 'default',
              'element'   => '#main-menu li a:hover',
              'property'  => 'color',
            ),
            array(
              'choice'    => 'default',
              'element'   => '#main-menu li.active a',
              'property'  => 'color',
            ),
            array(
              'choice'    => 'default',
              'element'   => '#main-menu .dropdown-menu .menu-item a:hover',
              'property'  => 'color',
            ),
            array(
              'choice'    => 'default',
              'element'   => '.btn-primary',
              'property'  => 'background',
            )
            ,array(
              'choice'    => 'default',
              'element'   => 'a.featured-post-link',
              'property'  => 'background',
            ),
            array(
              'choice'    => 'default',
              'element'   => '.btn-primary',
              'property'  => 'border-color',
            ),
            array(
              'choice'    => 'default',
              'element'   => '.about-author-social-wrapper a.about-author-social',
              'property'  => 'color',
            ),
            array(
              'choice'    => 'default',
              'element'   => '.comments-area input[type="submit"]',
              'property'  => 'background',
            ),
            array(
              'choice'    => 'default',
              'element'   => '.entry-content blockquote:after',
              'property'  => 'color',
            ),
            array(
              'choice'    => 'default',
              'element'   => '.x-next:hover .line',
              'property'  => 'background',
            ),
            array(
              'choice'    => 'default',
              'element'   => '.x-prev:hover .line',
              'property'  => 'background',
            ),
            array(
              'choice'    => 'default',
              'element'   => '.x:hover .line',
              'property'  => 'background',
            ),
            array(
              'choice'    => 'default',
              'element'   => 'blockquote:before',
              'property'  => 'background',
            ),
            array(
              'choice'    => 'default',
              'element'   => 'blockquote:after',
              'property'  => 'background',
            ),
            array(
              'choice'    => 'default',
              'element'   => '.post-link span:after',
              'property'  => 'border-color',
            ),
            array(
              'choice'    => 'default',
              'element'   => '.nav-previous span:after',
              'property'  => 'border-color',
            ),
            array(
              'choice'    => 'default',
              'element'   => '.nav-next span:after',
              'property'  => 'border-color',
            ),
            array(
              'choice'    => 'default',
              'element'   => '.post-categories a, .featured-post-categories a',
              'property'  => 'color',
            ),
        ),
    ) );

twinkle_Kirki::add_section( 'single', array(
    'title'      => esc_html__( 'Post Settings', 'twinkle' ),
    'priority'   => 3,
    'capability' => 'edit_theme_options',
) );
    
    twinkle_Kirki::add_field( 'twinkle', array(
        'type'        => 'switch',
        'settings'    => 'enable_about_the_author',
        'label'       => __( 'Show about the author info?', 'twinkle' ),
        'section'     => 'single',
        'default'     => '1',
        'priority'    => 10,
         'choices'     => array(
            'on'  => esc_html__( 'On', 'twinkle' ),
            'off' => esc_html__( 'Off', 'twinkle' ),
        ),
    ) );

    twinkle_Kirki::add_field( 'twinkle', array(
        'type'        => 'switch',
        'settings'    => 'enable_similar_posts',
        'label'       => __( 'Enable similar posts?', 'twinkle' ),
        'section'     => 'single',
        'default'     => '1',
        'priority'    => 10,
         'choices'     => array(
            'on'  => esc_html__( 'On', 'twinkle' ),
            'off' => esc_html__( 'Off', 'twinkle' ),
        ),
    ) );
twinkle_Kirki::add_section( 'footer', array(
    'title'      => esc_html__( 'Footer Settings', 'twinkle' ),
    'priority'   => 3,
    'capability' => 'edit_theme_options',
) );
    
    twinkle_Kirki::add_field( 'twinkle', array(
        'type'        => 'color',
        'settings'    => 'footer_bg_color',
        'label'       => __( 'Footer Background Color', 'twinkle' ),
        'section'     => 'footer',
        'default'     => '#f3f5f8',
        'priority'    => 10,
        'alpha'       => false,
        'output'    => array(
            array(
              'choice'    => 'default',
              'element'   => '#wrapper-footer-full',
              'property'  => 'background',
            ),
        ),
    ) );

    twinkle_Kirki::add_field( 'twinkle', array(
        'type'        => 'radio',
        'settings'    => 'footer_columns',
        'label'       => __( 'Footer Columns', 'twinkle' ),
        'section'     => 'footer',
        'default'     => 'disable',
        'priority'    => 10,
        'choices'     => array(
            'one-column'    => esc_html__( 'One Column', 'twinkle' ),
            'two-columns'   => esc_html__( 'Two Columns', 'twinkle' ),
            'three-columns' => esc_html__( 'Three Columns', 'twinkle' ),
            'four-columns'  => esc_html__( 'Four Columns', 'twinkle' ),
            'disable'       => esc_html__( 'Disable Footer', 'twinkle' ),
        ),
    ) );


/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function twinkle_customize_preview_js() {
	wp_enqueue_script( 'twinkle_customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), '20171011', true );
}
add_action( 'customize_preview_init', 'twinkle_customize_preview_js' );